==> camel-k-crds-2.3.1-sources.jar: org/apache/camel/v1/IntegrationProfileSpec.java <==
package org.apache.camel.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"build","kamelet","traits"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class IntegrationProfileSpec implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * specify how to build the Integration/IntegrationKits
     */
    @com.fasterxml.jackson.annotation.JsonProperty("build")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("specify how to build the Integration/IntegrationKits")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Build build;

    public org.apache.camel.v1.integrationprofilespec.Build getBuild() {
        return build;
    }

    public void setBuild(org.apache.camel.v1.integrationprofilespec.Build build) {
        this.build = build;
    }

    /**
     * configuration to be executed to all Kamelets controlled by this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kamelet")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("configuration to be executed to all Kamelets controlled by this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Kamelet kamelet;

    public org.apache.camel.v1.integrationprofilespec.Kamelet getKamelet() {
        return kamelet;
    }

    public void setKamelet(org.apache.camel.v1.integrationprofilespec.Kamelet kamelet) {
        this.kamelet = kamelet;
    }

    /**
     * list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("traits")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Traits traits;

    public org.apache.camel.v1.integrationprofilespec.Traits getTraits() {
        return traits;
    }

    public void setTraits(org.apache.camel.v1.integrationprofilespec.Traits traits) {
        this.traits = traits;
    }
}

==> camel-k-crds-2.4.0-sources.jar: org/apache/camel/v1/IntegrationProfileSpec.java <==
package org.apache.camel.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"build","kamelet","traits"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
@lombok.ToString()
@lombok.EqualsAndHashCode()
@io.sundr.builder.annotations.Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.LabelSelector.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Container.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.EnvVar.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.ContainerPort.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.Volume.class),
    @io.sundr.builder.annotations.BuildableReference(io.fabric8.kubernetes.api.model.VolumeMount.class)
})
public class IntegrationProfileSpec implements io.fabric8.kubernetes.api.builder.Editable<IntegrationProfileSpecBuilder>, io.fabric8.kubernetes.api.model.KubernetesResource {

    @java.lang.Override
    public IntegrationProfileSpecBuilder edit() {
        return new IntegrationProfileSpecBuilder(this);
    }

    /**
     * specify how to build the Integration/IntegrationKits
     */
    @com.fasterxml.jackson.annotation.JsonProperty("build")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("specify how to build the Integration/IntegrationKits")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Build build;

    public org.apache.camel.v1.integrationprofilespec.Build getBuild() {
        return build;
    }

    public void setBuild(org.apache.camel.v1.integrationprofilespec.Build build) {
        this.build = build;
    }

    /**
     * configuration to be executed to all Kamelets controlled by this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("kamelet")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("configuration to be executed to all Kamelets controlled by this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Kamelet kamelet;

    public org.apache.camel.v1.integrationprofilespec.Kamelet getKamelet() {
        return kamelet;
    }

    public void setKamelet(org.apache.camel.v1.integrationprofilespec.Kamelet kamelet) {
        this.kamelet = kamelet;
    }

    /**
     * list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile
     */
    @com.fasterxml.jackson.annotation.JsonProperty("traits")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("list of traits to be executed for all the Integration/IntegrationKits built from this IntegrationProfile")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private org.apache.camel.v1.integrationprofilespec.Traits traits;

    public org.apache.camel.v1.integrationprofilespec.Traits getTraits() {
        return traits;
    }

    public void setTraits(org.apache.camel.v1.integrationprofilespec.Traits traits) {
        this.traits = traits;
    }
}
